@@ -1,4 +1,10 @@
 from typing import Tuple
+import logging
+
+
+logging.basicConfig()
+diskos_logger = logging.getLogger("Diskos")
+diskos_logger.setLevel(logging.INFO)
 
 
 def split_on_last_occurrence(val: str, delim: str) -> Tuple[str, str]:
